@@ -5,7 +5,7 @@
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
  *                      2004, 2005, 2006, 2007, 2008
- *                      2009  Henrik Sandklef                    
+ *                      2009, 2010  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -847,4 +847,21 @@ xnee_set_stderr_feedback(xnee_data *xd);
 int 
 xnee_set_no_feedback(xnee_data *xd);
 
+int
+xnee_has_xinput2(xnee_data *xd);
+
+int
+xnee_set_replay_backend(xnee_data *xd, int replay_backend);
+
+int
+xnee_set_replay_backend_name(xnee_data *xd, char *replay_backend);
+
+#define xnee_is_swinput_playback(xd) (xd->replay_backend == XNEE_REPLAY_SWINPUT)
+
+int
+xnee_set_forced_core_device_events(xnee_data *xd);
+
+int
+xnee_unset_forced_core_device_events(xnee_data *xd);
+
 #endif /* XNEE_SETGET_H */ 
