@@ -170,8 +170,8 @@ xnee_replay_event_handler_sleep_amt(xnee_data* xd,
 				     record_last_diff, 
 				     record_first_diff ) ; 
     }
-  
-  /*
+
+  /*  
     printf ("xnee_calc_sleep_amount : %lu : (%lu) : %lu :  %lu ===>  %d\n",     
 	    last_diff, 
 	    first_diff,  
@@ -180,7 +180,6 @@ xnee_replay_event_handler_sleep_amt(xnee_data* xd,
 	    sleep_amt);
     fflush(stdout);
   */
-  
 
   return sleep_amt;
 }
@@ -272,6 +271,7 @@ xnee_replay_event_handler( xnee_data* xd,
 	      x      = (int) xindata->u.event.x ; 
 	      y      = (int) xindata->u.event.y ; 
 
+
 	      if (xnee_is_screen_ok(xd, screen))
 		{
 		  /* xnee_set_verbose(xd); */
@@ -423,8 +423,6 @@ xnee_fake_key_event_impl  (xnee_data* xd, int keycode, Bool bo, int dtime, int d
 	}
       else
 	{
-	  printf ("fake key %d   in %d\n",
-		  keycode, dtime);
 	  xnee_fake_sleep (dtime);
 	  xnee_verbose((xd, "XTestFakeKeyEvent (%d, %d, %d, %d ))\n",
 			(int) xd->fake, 
@@ -618,7 +616,6 @@ xnee_fake_motion_event_impl (xnee_data* xd,
   xnee_verbose((xd, "---> xnee_fake_motion_event\n"));
   xnee_verbose((xd, "---  delay = %d\n", (int)dtime));
 
-  
   if (!xnee_is_recorder (xd))
     {
       new_x = xnee_resolution_newx(xd,x) + xd->res_info.x_offset;
