@@ -4,7 +4,8 @@
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 
- *                 2005, 2006, 2007, 2009 Henrik Sandklef                    
+ *                 2005, 2006, 2007, 2009, 2010
+ *                 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -244,14 +245,12 @@ xnee_print_list(void)
 }
 
 
-int 
+static int 
 xnee_add_to_list2(xnee_data *xd, int type, int ev)
 {
    int i ;
    struct xnee_range *xrp;
 
-
-
    /* An item is added, set recording active */
    xd->record_setup->active = 1;
    
@@ -599,7 +598,7 @@ xnee_add_range (xnee_data* xd,
       else
 	{
 	  /* the work around above should probably be removed any time ... errrh */
-	  fprintf(stderr, "BEWARE: this code should not be released without serious checking, which has not been performed, since you see this text\n");
+	  fprintf(stderr, "NOTIFICATION: If you have problem with Xnee and recording device events: File a bug report including this text.\n");
 	}
       
     }
@@ -630,7 +629,6 @@ xnee_parse_range (xnee_data *xd,int type, char *range)
 {
   char buf[DATA_NAME_SIZE_MAX];
   int next;
-  int len;
   int ret=0;
   int range_len=strlen(range);
 
@@ -650,7 +648,6 @@ xnee_parse_range (xnee_data *xd,int type, char *range)
 	}
       strncpy(buf,range,next);
       buf[next]='\0';
-      len =strlen(range);
       range+=next+1;
       range_len=range_len - next - 1;
       xnee_verbose((xd, " -- calling xnee_add_range_str (%d, %d, %s) \n" , (int)xd, type, buf));
