@@ -42,6 +42,8 @@
 #include "libxnee/xnee_utils.h"
 #include "libxnee/xnee_strings.h"
 #include "libxnee/xnee_display.h"
+#include "libxnee/xnee_xinput.h"
+
 
 
 #ifdef DEBUG_DISPATCHER
@@ -103,6 +105,10 @@ xnee_get_screen_nr(xnee_data *xd, Display *dpy, Window recorded_root)
       Screen *scr;
       scr = ScreenOfDisplay(dpy,i);
       disp_root = RootWindowOfScreen(scr);
+
+      /* printf ("Loop: i=%d scr=%d dr=%d   rr=%d\n",  */
+      /* 	      i, scr, disp_root, recorded_root); */
+
       if ( disp_root == recorded_root )
 	{
 	  keep_looping = 0 ;
@@ -111,6 +117,9 @@ xnee_get_screen_nr(xnee_data *xd, Display *dpy, Window recorded_root)
       i++;
     } while ( (i<nr_screens) && ( keep_looping ) );
   
+  /* printf ("display %d   nr of screens %d      this:%d\n", */
+  /* 	  dpy, nr_screens, this_screen); */
+
   /* If we didn't find a screen, bail out */
   if ( this_screen == -1)
     {
@@ -142,6 +151,7 @@ xnee_record_handle_event_printer(xnee_data * xd,
   unsigned int screen ;
   char *win_name;
   int do_print = 1;
+
   
   out = xd->out_file;
 
@@ -220,7 +230,7 @@ xnee_record_handle_event_printer(xnee_data * xd,
 	       xrec_data->event.u.u.detail,
 	       xrecintd->server_time
 	       );
-      ret = xnee_fake_button_event (xd, (int)xrec_data->event.u.u.detail , True, CurrentTime);
+      ret = xnee_fake_button_event(xd, (int)xrec_data->event.u.u.detail , True, CurrentTime);
       XNEE_RETURN_IF_ERR(ret);
       break;
     case ButtonRelease:
@@ -229,39 +239,42 @@ xnee_record_handle_event_printer(xnee_data * xd,
 	       xrec_data->event.u.u.detail,
 	       xrecintd->server_time
 	       );
-      ret = xnee_fake_button_event (xd,  (int)xrec_data->event.u.u.detail, False, CurrentTime);
+      ret = xnee_fake_button_event(xd,  (int)xrec_data->event.u.u.detail, False, CurrentTime);
       XNEE_RETURN_IF_ERR(ret);
       
       break;
     case MotionNotify:  
       kc = 0;
       ret = xnee_get_screen_nr(xd, 
-				  xd->data,
-				  xrec_data->event.u.keyButtonPointer.root);
-      if (ret<0)
+			       xd->data,
+			       xrec_data->event.u.keyButtonPointer.root);
+      if (0)
 	{
-	  xnee_verbose((xd, "Could not find a screen, bailing out\n"));
-	  return XNEE_SCREEN_MISSING;
+	  /* Discarding core event that seems to have come from XI */
+	  /* ... anyhow, it's recorded as an XI event  */
+	  ret = XNEE_OK;
+	}
+      else
+	{
+	  screen = ret;
+	  do_print = xnee_save_or_print(xd, kc, XNEE_GRAB_MOUSE);
+	  fprintf (out,"0,%u,%d,%d,0,0,%u,%lu\n",
+		   event_type,
+		   xrec_data->event.u.keyButtonPointer.rootX,
+		   xrec_data->event.u.keyButtonPointer.rootY,
+		   screen,
+		   xrecintd->server_time
+		   );
+	  
+	  
+	  xd->xnee_info.last_motion = True ;
+	  ret = xnee_fake_motion_event (xd,
+					screen, 
+					xrec_data->event.u.keyButtonPointer.rootX, 
+					xrec_data->event.u.keyButtonPointer.rootY, 
+					CurrentTime);
+	  XNEE_RETURN_IF_ERR(ret);
 	}
-      screen = ret;
-
-      do_print = xnee_save_or_print(xd, kc, XNEE_GRAB_MOUSE);
-      fprintf (out,"0,%u,%d,%d,0,0,%u,%lu\n",
-	       event_type,
-	       xrec_data->event.u.keyButtonPointer.rootX,
-	       xrec_data->event.u.keyButtonPointer.rootY,
-	       screen,
-	       xrecintd->server_time
-	       );
-      
-      
-      xd->xnee_info.last_motion = True ;
-      ret = xnee_fake_motion_event (xd,
-				    screen, 
-				    xrec_data->event.u.keyButtonPointer.rootX, 
-				    xrec_data->event.u.keyButtonPointer.rootY, 
-				    CurrentTime);
-      XNEE_RETURN_IF_ERR(ret);
       
       break;
     case CreateNotify:
@@ -349,12 +362,20 @@ xnee_record_handle_event_printer(xnee_data * xd,
 	}
       break;
     default:
-      XNEE_DEBUG ( (stderr ," -- xnee_record_handle_event() at 6  \n"  ));
-      fprintf (out,"0,%u,0,0,0,0,0,%lu\n", 
-	       event_type,
-	       xrecintd->server_time
-	       );
-      break;
+      {
+	ret = xnee_handle_xinput_event(xd, 
+				       event_type, 
+				       xrec_data,
+				       xrecintd->server_time);
+
+	if ( ret != 0 )
+	  {
+	    fprintf (out,"0,%u,0,0,0,0,0,%lu\n", 
+		     event_type,
+		     xrecintd->server_time);
+	  }
+	break;
+      }
     }
   
   return XNEE_OK;
@@ -374,7 +395,6 @@ xnee_record_handle_event ( xnee_data *xd, /*@null@*/ XRecordInterceptData *xreci
   unsigned int  event_type ;
   FILE *out ;
 
-
    if ( xrecintd==NULL )
    {
       return XNEE_RECORD_FAILURE;
@@ -731,7 +751,14 @@ xnee_setup_recordext (xnee_data *xd)
       return XNEE_OK;
     }
   
+  #ifdef  XNEE_XINPUT_SUPPORT
+     xnee_xinput_add_devices(xd);
+     xnee_record_print_record_range (xd, xnee_get_out_file (xd)) ;
+#endif /*  XNEE_XINPUT_SUPPORT */
 
+
+
+  
   ret = xnee_parse_range (xd, XNEE_DELIVERED_EVENT, "ReparentNotify");
   XNEE_RETURN_IF_ERR (ret);
 
@@ -773,7 +800,9 @@ xnee_has_record_extension(xnee_data *xd)
         ||
         (xd->control == NULL))
   {
-     return XNEE_RECORD_FAILURE;
+    fprintf(stderr, "cannot look for RECORD extension withou xnee_data or control display %d %d \n", 
+	    xd, xd->control);
+    return XNEE_RECORD_FAILURE;
   }
 
   if( XRecordQueryVersion(xd->control, 
@@ -844,6 +873,7 @@ xnee_setup_recording(xnee_data *xd)
 			 xd->record_setup->xids,1, 
 			 xd->record_setup->range_array, 
 			 nr_of_ranges);
+  XFlush(context_display);
 
   XFlush(xd->control);
   XFlush(xd->data);
@@ -883,14 +913,16 @@ xnee_unsetup_recording(xnee_data *xd)
 
   xnee_verbose((xd, "---> xnee_unsetup_recording\n"));
 
-
   if (xd->record_setup->rContext != 0)
     {
       xnee_verbose((xd, "---  disabling context %d on %d \n", 
-		    (int)xd->record_setup->rContext, context_display));
-
-      (void)XRecordDisableContext(xd->control, xd->record_setup->rContext); 
+		    (int)xd->record_setup->rContext, 
+		    context_display));
+  
+      (void)XRecordDisableContext(xd->control, 
+				  xd->record_setup->rContext);
 
+      xnee_verbose((xd, "---  freeing context \n"));
       (void)XRecordFreeContext(xd->control, 
 			       xd->record_setup->rContext);
 
