@@ -499,8 +499,7 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 		case XNEE_PROTO_XINPUT_EVENT_SLAVE:
 		  xnee_verbose((xd, "READ A XINPUT EVENT SLAVE\n")); 
 		  
-		  xnee_replay_update_dev_ctr(xd, 
-					     xindata.u.xievent.type);
+		  xnee_replay_update_dev_ctr(xd, xindata.u.xievent.type);
 		  
 		  ret = xnee_replay_synchronize (xd);
 		  if (ret != XNEE_OK)
