@@ -46,6 +46,7 @@
 #include "libxnee/xnee_session.h"
 #include "libxnee/xnee_fileop.h"
 #include "libxnee/xnee_alloc.h"
+#include "libxnee/xnee_xinput.h"
 
 xnee_data *xd_global;
 
@@ -290,7 +291,7 @@ xnee_init(xnee_data* xd)
   int ret ; 
   int i ; 
   char *tmp;
-  
+
   if (xd == NULL) 
     {
       return XNEE_MEMORY_FAULT;
@@ -408,6 +409,9 @@ xnee_init(xnee_data* xd)
   xd->res_info.x_offset = 0;
   xd->res_info.y_offset = 0;
 
+  xnee_disable_xinput(xd);
+  xnee_init_xinput(xd);
+
   /* Init Recording variables
    * Since those are used when recording and replaying. */
   xnee_record_init (xd);
@@ -417,6 +421,8 @@ xnee_init(xnee_data* xd)
 
   xnee_set_x_server_version(xd);
 
+  xnee_set_replay_backend(xd, XNEE_REPLAY_XNEE);
+
   /* Set the signal handler the libxnee's built in */ 
   (void) signal (SIGINT, signal_handler);
   
@@ -534,27 +540,41 @@ xnee_rep_prepare(xnee_data *xd)
 /*   ret = xnee_set_ranges(xd); */
 /*   XNEE_RETURN_IF_ERR (ret); */
 
-
   xnee_set_events_replayed(xd,0);
 
-  if ( xnee_is_replayer(xd) != 0 )
-  {
-    xnee_verbose((xd, "Entering main loop (replayer) to read META data \n"));
-    ret = xnee_replay_main_loop(xd, XNEE_REPLAY_READ_META_DATA);
-  }
-
-  /* 
-   * Setup / Test Displays and Extensions  
-   *
-   */
-  xnee_verbose((xd, "-- xnee_rep_prepare - setup display\n"));
-
   ret = xnee_setup_display (xd);
   if (ret!=XNEE_OK)
     {
       xnee_verbose((xd, "<-- xnee_rep_prepare returning %d\n", ret));
       return ret;
     }
+
+
+  if ( xnee_is_replayer(xd) != 0 )
+  {
+
+    xnee_verbose((xd, "Entering main loop (replayer) to read META data \n"));
+    ret = xnee_replay_main_loop(xd, XNEE_REPLAY_READ_META_DATA);
+    if (!( ( ret == XNEE_REPLAY_READ_META_DATA )  || 
+	   ( ret == XNEE_REPLAY_READ_REPLAY_DATA) || 
+	   ( ret == XNEE_OK ) ))
+      {
+	return ret;
+      }
+  }
+
+  /* 
+   * Setup / Test Displays and Extensions  
+   *
+   */
+  xnee_verbose((xd, "-- xnee_rep_prepare - setup display\n"));
+  ret = xnee_setup_display (xd);
+  if (ret!=XNEE_OK)
+    {
+      xnee_verbose((xd, "<-- xnee_rep_prepare returning %d\n", ret));
+      return ret;
+    }
+
   
   xnee_verbose((xd, "-- xnee_rep_prepare - setup record ext \n"));
 
