@@ -7,7 +7,7 @@
  *                      2004, 2009, 2010  Henrik Sandklef
  *                                                                   
  * This program is free software; you can redistribute it and/or     
- * modify it under the terms of the GNU General Public License       
+ * modify1 it under the terms of the GNU General Public License       
  * as published by the Free Software Foundation; either version 3    
  * of the License, or any later version.                             
  *                                                                   
@@ -1214,7 +1214,7 @@ xnee_set_project_file(xnee_data *xd, char *name)
 
   if (name == NULL)
     {
-      ret = XNEE_WRONG_PARAMS;
+      return XNEE_WRONG_PARAMS;
     }
 
   ret = xnee_set_rc_byname (xd, name);
@@ -1859,3 +1859,55 @@ xnee_is_no_reparent_recording(xnee_data *xd)
 }
 
 
+int
+xnee_set_replay_backend(xnee_data *xd, int replay_backend)
+{
+  if (( replay_backend < 0 ) || (replay_backend >= XNEE_REPLAY_LAST))
+    {
+      return XNEE_REPLAY_BACKEND_FAILURE;
+    }
+  xd->replay_backend = replay_backend;
+  return XNEE_OK;
+}
+
+int
+xnee_set_replay_backend_name(xnee_data *xd, char *replay_backend)
+{
+  if (replay_backend==NULL)
+    {
+      return XNEE_REPLAY_BACKEND_FAILURE;
+    }
+  if (strncmp(replay_backend, 
+	      XNEE_REPLAY_XNEE_STRING, 
+	      strlen(XNEE_REPLAY_XNEE_STRING))==0)
+    {
+      return xnee_set_replay_backend(xd, XNEE_REPLAY_XNEE);
+    }
+  else if (strncmp(replay_backend, 
+		   XNEE_REPLAY_SWINPUT_STRING, 
+		   strlen(XNEE_REPLAY_SWINPUT_STRING))==0)
+    {
+      return xnee_set_replay_backend(xd, XNEE_REPLAY_SWINPUT);
+    }
+  return XNEE_REPLAY_BACKEND_FAILURE;
+}
+
+int
+xnee_is_forced_core_device_events(xnee_data *xd)
+{
+  return (xd->xi_data.forced_core_replay != 0) ;
+}
+
+int
+xnee_set_forced_core_device_events(xnee_data *xd)
+{
+  xd->xi_data.forced_core_replay = 1 ;
+  return XNEE_OK;
+}
+
+int
+xnee_unset_forced_core_device_events(xnee_data *xd)
+{
+  xd->xi_data.forced_core_replay = 0 ;
+  return XNEE_OK;
+}
